==> cmsmadesimple-1.5.3.tgz: cms/modules/FileManager/lang/ext/nl_NL.php <==
<?php
$lang['friendlyname'] = 'FileManager ';
$lang['permission'] = 'Gebruik van de File Manager-module';
$lang['permissionadvanced'] = 'Gevorderd gebruik van de File Manager-module';
$lang['moddescription'] = 'Beheer van bestanden en mappen in de Uploads-map';
$lang['installed'] = 'File Manager versie %s ge&iuml;nstalleerd';
$lang['postinstall'] = 'File Manager-module is ge&iuml;nstalleerd';
$lang['uninstalled'] = 'File Manager-module gede&iuml;nstalleerd';
$lang['really_uninstall'] = 'Weet u zeker dat de File Manager-module gede&iuml;nstalleerd moet worden';
$lang['upgraded'] = 'File Manager-module is upgraded naar versie %s';
$lang['fileview'] = 'Bestandsweergave';
$lang['switchtofileview'] = 'Schakel naar bestandsweergave';
$lang['settings'] = 'Instellingen';
$lang['savesettings'] = 'Bewaar instellingen';
$lang['filename'] = 'Bestandsnaam';
$lang['fileinfo'] = 'Bestandsinformatie';
$lang['fileowner'] = 'Bestandseigenaar';
$lang['fileperms'] = 'Rechten';
$lang['filesize'] = 'Grootte';
$lang['filedate'] = 'Datum';
$lang['actions'] = 'Acties';
$lang['delete'] = 'Verwijder';
$lang['notwritable'] = 'Niet schrijfbaar';
$lang['filetoobig'] = 'te groot. Upload is afgebroken.';
$lang['unknown'] = 'Onbekend';
$lang['fileoutsideuploads'] = 'Je hebt geen autorisatie om bestanden buiten de uploads-folder aan te passen! (Daarvoor is Advanced File Management permissie nodig)';
$lang['writable'] = 'Schrijfbaar';
$lang['writeprotected'] = 'Schrijf beveiligd';
$lang['bytes'] = 'bytes ';
$lang['kb'] = 'kb ';
$lang['mb'] = 'mb ';
$lang['files'] = 'bestanden';
$lang['bytesin'] = 'bytes in ';
$lang['in'] = 'in ';
$lang['file'] = 'bestand';
$lang['fileno'] = 'Bestandsnr.';
$lang['subdirs'] = 'submappen';
$lang['subdir'] = 'submap';
$lang['and'] = 'en';
$lang['confirmsingledelete'] = 'Weet u het zeker?';
$lang['confirmsingledirdelete'] = 'Weet u zeker dat deze map verwijderd moet worden?';
$lang['dirtreedeletesuccess'] = 'De map en de inhoud is verwijderd.';
$lang['dirtreedeletefail'] = 'Er is een fout opgetreden bij het verwijderen van deze map. Een deel van de inhoud kan echter verwijderd zijn.';
$lang['singlefiledeletesuccess'] = 'Het bestand is verwijderd';
$lang['filedeletesuccess'] = 'is verwijderd';
$lang['singlefiledeletefail'] = 'Er is een fout opgetreden bij het verwijderen van het bestand';
$lang['filedeletefail'] = 'is niet verwijderd vanwege een fout';
$lang['singledirdeletesuccess'] = 'De map is verwijderd';
$lang['singledirdeletefail'] = 'Een fout is opgetreden bij het verwijderen van de map (is deze leeg?)';
$lang['deleteselected'] = 'Verwijder de geselecteerde bestanden';
$lang['confirmselected'] = 'Weet u het zeker?';
$lang['confirmdeleteselected'] = 'Weet je zeker dat de geselecteerde bestanden moeten worden verwijderd?';
$lang['deleteselectedcancelled'] = 'Verwijderen van geselecteerde bestanden geannuleerd';
$lang['recursetext'] = 'Recursief in mappen';
$lang['nofilesselected'] = 'Geen bestanden geselecteerd';
$lang['moveselected'] = 'Verplaats de geselecteerde bestanden';
$lang['copyselected'] = 'Kopieer de geselecteerde bestanden';
$lang['selecttargetdir'] = 'Selecteer de doel-directorie voor het verplaatsen/kopieren';
$lang['movedto'] = 'verplaatst naar';
$lang['copiedto'] = 'gekopieerd naar';
$lang['couldnotmove'] = 'kon niet worden verplaatst';
$lang['couldnotcopy'] = 'kon niet worden gekopieerd';
$lang['rename'] = 'Naam wijzigen';
$lang['newname'] = 'Nieuwe naam:';
$lang['renamesuccess'] = 'Bestandsnaam gewijzigd';
$lang['renamefailure'] = 'Naam wijzigen mislukt';
$lang['renamecancelled'] = 'Naam wijzigen geannuleerd';
$lang['owner'] = 'Eigenaar';
$lang['group'] = 'Groep';
$lang['others'] = 'Overigen';
$lang['newpermissions'] = 'Nieuwe permissies:';
$lang['setpermissions'] = 'Plaats permissies';
$lang['permissionstyle'] = 'Permissie style';
$lang['rwxstyle'] = 'rwx style ';
$lang['755style'] = '755 style ';
$lang['quickmode'] = 'Snelle chmod (zoals 777)';
$lang['chmod'] = 'Wijzig permissies';
$lang['chmodselected'] = 'Wijzig permissies op geselecteerde bestanden';
$lang['chmodsuccess'] = 'Permissies gewijzigd';
$lang['chmodfailure'] = 'Permissies wijzigen mislukt';
$lang['chmodcancelled'] = 'Permissies wijzigen geannuleerd';
$lang['dirchmodfailmulti'] = 'Changing permissions on the directory failed, some of it&#039;s content may have gotten new permissions, though.';
$lang['dirchmodsuccessmulti'] = 'Changing permissions on the directory and it&#039;s content was successful';
$lang['dirchmodsuccess'] = 'Mappermissies gewijzigd';
$lang['dirchmodfailure'] = 'Mappermissies wijzigen mislukt';
$lang['dirnotemptyconfirm'] = 'Deze map is niet leeg. Weet u zeker dat deze verwijderd moet worden en alle inhoud, inclusief de sub mappen?';
$lang['dirtreedeletecancelled'] = 'Verwijdering van de map afgebroken';
$lang['imsure'] = 'Ik weet het zeker';
$lang['cancel'] = 'Annuleer';
$lang['ok'] = 'Ok';
$lang['uploadnewfile'] = 'Upload nieuwe bestanden:';
$lang['unpackafterupload'] = 'Probeer het bestand uit te pakken na upload (alleen tgz en meeste zip-bestanden)?';
$lang['uploadsuccess'] = 'is ge-upload';
$lang['uploadfail'] = 'upload niet geslaagd';
$lang['unpacksuccess'] = 'is uitgepakt';
$lang['unpackfail'] = 'afgebroken met deze fout:';
$lang['packfileopenfail'] = 'Kon het ingepakte bestand niet openen om uit te pakken (niet-ondersteund formaat?)';
$lang['packfilewritefail'] = 'Kan het bestand &amp;s niet openen om naar te schrijven';
$lang['currentpath'] = 'Huidig pad:';
$lang['newdirname'] = 'Maak nieuwe map aan:';
$lang['newdirsuccess'] = 'De map is aangemaakt';
$lang['newdirfail'] = 'Er is een fout opgetreden bij het aanmaken van de map';
$lang['filedateformat'] = 'm/d/j u:m:s';
$lang['iconsize'] = 'Pictogramgrootte';
$lang['smallicons'] = 'Kleine pictogram';
$lang['largeicons'] = 'Grote pictogram';
$lang['thousanddelimiter'] = 'Duizendtal scheidingsteken';
$lang['none'] = 'Geen';
$lang['showthumbnails'] = 'Toon miniaturen';
$lang['showthumbnailshelp'] = 'Activeren zorgt dat miniaturen worden getoond van afbeeldingen wanneer deze aanwezig zijn en zal het miniatuur-bestand verbergen. De-activeren zorgt dat alle bestanden worden getoond.';
$lang['uploadfilesto'] = 'Upload bestanden naar: ';
$lang['uploadview'] = 'Upload bestanden';
$lang['uploadboxes'] = 'Aantal uploadboxes';
$lang['nothinguploaded'] = 'Niets geupload';
$lang['unsupportedarchive'] = 'Niet-ondersteund archiefformaat';
$lang['uploadmethod'] = 'Upload-methode';
$lang['uploaderstandard'] = 'Standaard html invoermethode (staat uitpakken toe)';
$lang['enableadvanced'] = 'Sta gevorderdenmodus toe?';
$lang['advancedhelp'] = 'Geeft u toegang tot het gehele cmsms bestandssysteem, niet alleen /uploads/ (indien toegestaan)';
$lang['showhiddenfileshelp'] = 'Alleen effectief in de gevorderenmodus';
$lang['showhiddenfiles'] = 'Toon verborgen bestanden';
$lang['settingsconfirmsingledelete'] = 'Bevestig verwijdering van een enkel bestand?';
$lang['settingssaved'] = 'Instellingen bewaard';
$lang['help'] = '		<h3>Wat doet het?</h3>
		<p>Deze module verzorgt bestandsbeheerfunctionaliteit en maakt daarmee hopelijk het nogal oude, ingebouwde file management overbodig.</p>
		<h3>Hoe gebruikt u het</h3>
		<p>Selecteer File Manager uit het Inhoudsmenu. Als de oude filemanager nog aanwezig is, kies dan de versie die het laagst in het menu staat.</p>';
$lang['utma'] = '156861353.799969050.1225024056.1234730819.1234793451.10';
$lang['utmz'] = '156861353.1232355789.5.3.utmcsr=forum.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/index.php/topic,29866.0.html';
$lang['utmb'] = '156861353';
$lang['utmc'] = '156861353';
?>

==> cmsmadesimple-1.6.4.tgz: cms/modules/FileManager/lang/ext/nl_NL.php <==
<?php
$lang['friendlyname'] = 'Bestandsbeheer ';
$lang['permission'] = 'Gebruik van de Bestandsbeheer-module';
$lang['permissionadvanced'] = 'Gevorderd gebruik van de Bestandsbeheer-module';
$lang['moddescription'] = 'Beheer van bestanden en mappen in de Uploads-map';
$lang['installed'] = 'File Manager versie %s ge&iuml;nstalleerd';
$lang['postinstall'] = 'File Manager-module is ge&iuml;nstalleerd';
$lang['uninstalled'] = 'File Manager-module gede&iuml;nstalleerd';
$lang['really_uninstall'] = 'Weet u zeker dat de File Manager-module gede&iuml;nstalleerd moet worden';
$lang['upgraded'] = 'File Manager-module is upgraded naar versie %s';
$lang['fileview'] = 'Bestandsweergave';
$lang['switchtofileview'] = 'Schakel naar bestandsweergave';
$lang['settings'] = 'Instellingen';
$lang['savesettings'] = 'Bewaar instellingen';
$lang['filename'] = 'Bestandsnaam';
$lang['fileinfo'] = 'Bestandsinformatie';
$lang['fileowner'] = 'Bestandseigenaar';
$lang['fileperms'] = 'Rechten';
$lang['filesize'] = 'Grootte';
$lang['filedate'] = 'Datum';
$lang['actions'] = 'Acties';
$lang['delete'] = 'Verwijder';
$lang['notwritable'] = 'Niet schrijfbaar';
$lang['filetoobig'] = 'is te groot. Upload is afgebroken.';
$lang['unknown'] = 'Onbekend';
$lang['fileoutsideuploads'] = 'Je hebt geen autorisatie om bestanden buiten de uploads-folder aan te passen! (Daarvoor is Advanced File Management permissie nodig)';
$lang['writable'] = 'Schrijfbaar';
$lang['writeprotected'] = 'Schrijf beveiligd';
$lang['bytes'] = 'bytes ';
$lang['kb'] = 'kb ';
$lang['mb'] = 'mb ';
$lang['files'] = 'bestanden';
$lang['bytesin'] = 'bytes in ';
$lang['in'] = 'in ';
$lang['file'] = 'bestand';
$lang['fileno'] = 'Bestandsnr.';
$lang['subdirs'] = 'submappen';
$lang['subdir'] = 'submap';
$lang['and'] = 'en';
$lang['confirmsingledelete'] = 'Weet u het zeker?';
$lang['confirmsingledirdelete'] = 'Weet u zeker dat deze map verwijderd moet worden?';
$lang['dirtreedeletesuccess'] = 'De map en de inhoud is verwijderd.';
$lang['dirtreedeletefail'] = 'Er is een fout opgetreden bij het verwijderen van deze map. Een deel van de inhoud kan echter verwijderd zijn.';
$lang['singlefiledeletesuccess'] = 'Het bestand is verwijderd';
$lang['filedeletesuccess'] = 'is verwijderd';
$lang['singlefiledeletefail'] = 'Er is een fout opgetreden bij het verwijderen van het bestand';
$lang['filedeletefail'] = ' is vanwege een fout niet verwijderd';
$lang['singledirdeletesuccess'] = 'De map is verwijderd';
$lang['singledirdeletefail'] = 'Een fout is opgetreden bij het verwijderen van de map (is deze leeg?)';
$lang['deleteselected'] = 'Verwijder de geselecteerde bestanden';
$lang['confirmselected'] = 'Weet u het zeker?';
$lang['confirmdeleteselected'] = 'Weet je zeker dat de geselecteerde bestanden moeten worden verwijderd?';
$lang['deleteselectedcancelled'] = 'Verwijderen van geselecteerde bestanden geannuleerd';
$lang['recursetext'] = 'Recursief in mappen';
$lang['nofilesselected'] = 'Geen bestanden geselecteerd';
$lang['moveselected'] = 'Verplaats de geselecteerde bestanden';
$lang['copyselected'] = 'Kopieer de geselecteerde bestanden';
$lang['selecttargetdir'] = 'Selecteer de doel-directorie voor het verplaatsen/kopieren';
$lang['movedto'] = 'verplaatst naar';
$lang['copiedto'] = 'gekopieerd naar';
$lang['couldnotmove'] = 'kon niet worden verplaatst';
$lang['couldnotcopy'] = 'kon niet worden gekopieerd';
$lang['rename'] = 'Naam wijzigen';
$lang['newname'] = 'Nieuwe naam:';
$lang['renamesuccess'] = 'Bestandsnaam gewijzigd';
$lang['renamefailure'] = 'Naam wijzigen mislukt';
$lang['renamecancelled'] = 'Naam wijzigen geannuleerd';
$lang['owner'] = 'Eigenaar';
$lang['group'] = 'Groep';
$lang['others'] = 'Overigen';
$lang['newpermissions'] = 'Nieuwe permissies:';
$lang['setpermissions'] = 'Plaats permissies';
$lang['permissionstyle'] = 'Permissie style';
$lang['rwxstyle'] = 'rwx style ';
$lang['755style'] = '755 style ';
$lang['quickmode'] = 'Snelle chmod (zoals 777)';
$lang['chmod'] = 'Wijzig permissies';
$lang['chmodselected'] = 'Wijzig permissies op geselecteerde bestanden';
$lang['chmodsuccess'] = 'Permissies gewijzigd';
$lang['chmodfailure'] = 'Permissies wijzigen mislukt';
$lang['chmodcancelled'] = 'Permissies wijzigen geannuleerd';
$lang['dirchmodfailmulti'] = 'Permissie wijzigen van deze map is mislukt, het kan echter wel zijn dat bepaalde bestanden wel gewijzigde rechten hebben gekregen.';
$lang['dirchmodsuccessmulti'] = 'Permissies wijzigen van de map en de inhoud is geslaagd';
$lang['dirchmodsuccess'] = 'Map permissies gewijzigd';
$lang['dirchmodfailure'] = 'Map permissies wijzigen mislukt';
$lang['dirnotemptyconfirm'] = 'Deze map is niet leeg. Weet u zeker dat deze verwijderd moet worden en alle inhoud, inclusief de submappen?';
$lang['dirtreedeletecancelled'] = 'Verwijdering van de map afgebroken';
$lang['imsure'] = 'Ik weet het zeker';
$lang['cancel'] = 'Annuleer';
$lang['ok'] = 'Ok';
$lang['uploadnewfile'] = 'Upload nieuwe bestanden:';
$lang['unpackafterupload'] = 'Probeer het bestand uit te pakken na upload (alleen tgz en meeste zip-bestanden)?';
$lang['uploadsuccess'] = 'is ge&uuml;pload';
$lang['uploadfail'] = 'upload niet geslaagd';
$lang['unpacksuccess'] = 'is uitgepakt';
$lang['unpackfail'] = 'afgebroken met deze fout:';
$lang['packfileopenfail'] = 'Kon het ingepakte bestand niet openen om uit te pakken (niet-ondersteund formaat?)';
$lang['packfilewritefail'] = 'Kan het bestand %s niet openen om naar te schrijven';
$lang['currentpath'] = 'Huidig pad:';
$lang['newdirname'] = 'Maak nieuwe map aan:';
$lang['newdirsuccess'] = 'De map is aangemaakt';
$lang['newdirfail'] = 'Er is een fout opgetreden bij het aanmaken van de map';
$lang['invalidnewdir'] = 'Naam van de nieuwe map geen karakters zoals /, \ en &#039;..&#039; bevatten';
$lang['filedateformat'] = 'm/d/J U:m:s';
$lang['iconsize'] = 'Pictogramgrootte';
$lang['smallicons'] = 'Kleine pictogrammen';
$lang['largeicons'] = 'Grote pictogrammen';
$lang['thousanddelimiter'] = 'Duizendtal scheidingsteken';
$lang['none'] = 'Geen';
$lang['space'] = 'ruimte';
$lang['showthumbnails'] = 'Toon miniaturen';
$lang['showthumbnailshelp'] = 'Activeren zorgt dat er miniaturen worden getoond van afbeeldingen, wanneer deze aanwezig zijn en zal ook het miniatuur-bestand zelf  verbergen. Deactiveren zorgt ervoor dat alle bestanden worden getoond.';
$lang['uploadfilesto'] = 'Upload bestanden naar: ';
$lang['uploadview'] = 'Upload bestanden';
$lang['uploadboxes'] = 'Aantal uploadvelden';
$lang['nothinguploaded'] = 'Niets ge&uuml;pload';
$lang['unsupportedarchive'] = 'Niet-ondersteund archiefformaat';
$lang['uploadmethod'] = 'Upload-methode';
$lang['uploaderstandard'] = 'Standaard html invoermethode (staat uitpakken toe)';
$lang['enableadvanced'] = 'Sta gevorderdenmodus toe?';
$lang['advancedhelp'] = 'Geeft u toegang tot het gehele CMSMS bestandssysteem, niet alleen /uploads/ (indien toegestaan)';
$lang['showhiddenfileshelp'] = 'Alleen effectief in de gevorderenmodus';
$lang['showhiddenfiles'] = 'Toon verborgen bestanden';
$lang['settingsconfirmsingledelete'] = 'Bevestig verwijdering van een enkel bestand?';
$lang['settingssaved'] = 'Instellingen bewaard';
$lang['help'] = '		<h3>Wat doet het?</h3>
		<p>Deze module verzorgt een bestandsbeheer functionaliteit</p>
		<h3>Hoe gebruikt u het</h3>
		<p>Selecteer Bestandsbeheer in het Inhoudsmenu.</p>';
$lang['utma'] = '156861353.1764090269059867100.1239886062.1247056319.1247079810.23';
$lang['utmz'] = '156861353.1247056319.22.2.utmccn=(referral)|utmcsr=forum.cmsmadesimple.org|utmcct=/index.php/topic,35313.0.html|utmcmd=referral';
$lang['utmb'] = '156861353';
$lang['utmc'] = '156861353';
?>
